@@ -61,11 +61,11 @@ async def pylav_credits(context: PyLavContext) -> None:
             ).format(
                 library_author_name_variable_do_not_translate="[Draper#6666](https://github.com/Drapersniper)",
                 library_url_variable_do_not_translate="https://github.com/PyLav/PyLav",
-                second_library_url_variable_do_not_translate="https://github.com/PyLav/PyLav-Cogs",
+                second_library_url_variable_do_not_translate="https://github.com/PyLav/Red-Cogs",
                 support_server_url_variable_do_not_translate="https://discord.com/invite/Sjh2TSCYQB",
                 crowdin_project_url_variable_do_not_translate="https://crowdin.com/project/pylav",
                 project_contributors_url_variable_do_not_translate="https://github.com/PyLav/PyLav/graphs/contributors",
-                second_project_contributors_url_variable_do_not_translate="https://github.com/PyLav/PyLav-Cogs/graphs/contributors",
+                second_project_contributors_url_variable_do_not_translate="https://github.com/PyLav/Red-Cogs/graphs/contributors",
                 buymeacoffee_url_variable_do_not_translate="https://www.buymeacoffee.com/draper",
                 github_sponsors_url_variable_do_not_translate="https://github.com/sponsors/Drapersniper",
             ),
